Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py	(revision 13076)
@@ -72,5 +72,5 @@
     grok.require('waeup.Public')
     form_fields = grok.AutoFields(IApplicantsRoot)
-    label = _('Applicant Section')
+    label = _('Applicants Section')
     pnav = 3
 
@@ -127,5 +127,5 @@
     grok.template('applicantsrootmanagepage')
     form_fields = grok.AutoFields(IApplicantsRoot)
-    label = _('Manage applicant section')
+    label = _('Manage applicants section')
     pnav = 3
     grok.require('waeup.manageApplication')
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/interfaces.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/interfaces.py	(revision 13076)
@@ -476,5 +476,5 @@
 
     This reduced interface is for former students or students who are not
-    users of the portal but have to pay supplementary fees.
+    student users of the portal but have to pay supplementary fees.
 
     This interface is used in browser components only. Thus we can't add
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py	(revision 13076)
@@ -204,5 +204,5 @@
         self.assertRaises(
             LinkNotFoundError,
-            self.browser.getLink, 'Manage applicant section')
+            self.browser.getLink, 'Manage applicants section')
         self.assertRaises(
             Unauthorized, self.browser.open, self.manage_root_path)
@@ -216,7 +216,7 @@
         self.browser.addHeader('Authorization', 'Basic mgr:mgrpw')
         self.browser.open(self.root_path)
-        self.assertTrue('Manage applicant section' in self.browser.contents)
+        self.assertTrue('Manage applicants section' in self.browser.contents)
         # There is a manage link
-        link = self.browser.getLink('Manage applicant section')
+        link = self.browser.getLink('Manage applicants section')
         link.click()
         self.assertEqual(self.browser.headers['Status'], '200 Ok')
@@ -252,5 +252,5 @@
         self.browser.getControl("Save").click()
         self.browser.open(self.root_path)
-        self.assertTrue('Manage applicant section' in self.browser.contents)
+        self.assertTrue('Manage applicants section' in self.browser.contents)
         # There is a search link
         link = self.browser.getLink('Find applicants')
@@ -562,5 +562,5 @@
         self.assertEqual(self.browser.headers['Status'], '200 Ok')
         self.assertFalse('Search' in self.browser.contents)
-        self.assertFalse('Manage applicant section' in self.browser.contents)
+        self.assertFalse('Manage applicants section' in self.browser.contents)
         # ... and can't access the manage page
         self.assertRaises(
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/utils.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/utils.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/utils.py	(revision 13076)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""General helper functions and utilities for the applicant section.
+"""General helper functions and utilities for the applicants section.
 """
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py	(revision 13076)
@@ -97,5 +97,5 @@
     grok.view(ApplicantsRootPage)
     grok.require('waeup.manageApplication')
-    text = _('Manage applicant section')
+    text = _('Manage applicants section')
 
 class ApplicantRegisterActionButton(ManageActionButton):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py	(revision 13076)
@@ -288,5 +288,5 @@
     grok.template('containermanagepage')
     pnav = 4
-    label = _('Manage student section')
+    label = _('Manage students section')
     search_button = _('Find student(s)')
     remove_button = _('Remove selected')
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/interfaces.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/interfaces.py	(revision 13076)
@@ -179,5 +179,5 @@
 class IStudentNavigation(IStudentNavigationBase):
     """Interface needed for navigation and logging. This interface is
-    implemented by all content classes in the student section.
+    implemented by all content classes in the students section.
     """
     student = Attribute('Student object of context')
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 13076)
@@ -257,5 +257,5 @@
         self.assertEqual(self.browser.headers['Status'], '200 Ok')
         self.assertEqual(self.browser.url, self.container_path)
-        self.browser.getLink("Manage student section").click()
+        self.browser.getLink("Manage students section").click()
         self.assertEqual(self.browser.headers['Status'], '200 Ok')
         self.assertEqual(self.browser.url, self.manage_container_path)
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py	(revision 13076)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""General helper functions and utilities for the student section.
+"""General helper functions and utilities for the students section.
 """
 import grok
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py	(revision 13076)
@@ -139,5 +139,5 @@
     grok.view(StudentsContainerPage)
     grok.require('waeup.manageStudent')
-    text = _('Manage student section')
+    text = _('Manage students section')
 
 class StudentsContainerAddActionButton(AddActionButton):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/vocabularies.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/vocabularies.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/vocabularies.py	(revision 13076)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Vocabularies and sources for the student section.
+"""Vocabularies and sources for the students section.
 """
 from zope.component import getUtility, queryUtility
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/catalog.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/catalog.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/catalog.py	(revision 13076)
@@ -57,5 +57,5 @@
 class CertificateCoursesIndexes(grok.Indexes):
     """This catalog is needed for automatic removal of certificate courses
-    and later for selection of course tickets in the student section.
+    and later for selection of course tickets in the students section.
     """
     grok.site(IUniversity)

Index: main/waeup.kofa/trunk/src/waeup/kofa/students/permissions.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/permissions.py	(revision 13073)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/permissions.py	(revision 13076)
@@ -17,9 +17,9 @@
 ##
 """
-Permissions for the student section.
+Permissions for the students section.
 """
 import grok
 
 # Student section permissions
 
 class HandleStudent(grok.Permission):
@@ -17,9 +17,9 @@
 import grok
 
-# Student section permissions
+# Students section permissions
 
 class HandleStudent(grok.Permission):